==> tuia-ecb-center-api-1.1.0.7-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixCashCowConfigReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;
import java.util.List;

public class MixCashCowConfigReq implements Serializable {
    private static final long serialVersionUID = -44975824246569508L;

    /*金币的成熟时间*/
    private Integer matureTime;

    /*新手引导金币数*/
    private Integer gainAtGuide;

    /*获得金币的区间配置 前N个 默认为5个*/
    private List<Integer> condition1;

    /*3-5*/
    private List<Integer> range1;

    /*获得金币的区间配置 前N个 默认为6-20个*/
    private List<Integer> condition2;

    /*3-5*/
    private List<Integer> range2;

    /*获得金币的区间配置 前N个 默认为21-50个*/
    private List<Integer> condition3;

    /*2-4*/
    private List<Integer> range3;

    /*获得金币的区间配置 前N个 默认为大于50个*/
    private List<Integer> condition4;

    /*1-2*/
    private List<Integer> range4;

    /*金币翻倍概率*/
    private Integer doubleRate;

    /*触发次数上线*/
    private Integer doubleTimesLimit;

    /*互动的概率*/
    private Integer interactionRate;

    /*互动的倍数*/
    private Integer interactionTimes;

    /*视频的概率*/
    private Integer videoRate;

    /*视频的倍数*/
    private Integer videoRateTimes;

    public Integer getMatureTime() {
        return matureTime;
    }

    public void setMatureTime(Integer matureTime) {
        this.matureTime = matureTime;
    }

    public Integer getGainAtGuide() {
        return gainAtGuide;
    }

    public void setGainAtGuide(Integer gainAtGuide) {
        this.gainAtGuide = gainAtGuide;
    }

    public List<Integer> getCondition1() {
        return condition1;
    }

    public void setCondition1(List<Integer> condition1) {
        this.condition1 = condition1;
    }

    public List<Integer> getRange1() {
        return range1;
    }

    public void setRange1(List<Integer> range1) {
        this.range1 = range1;
    }

    public List<Integer> getCondition2() {
        return condition2;
    }

    public void setCondition2(List<Integer> condition2) {
        this.condition2 = condition2;
    }

    public List<Integer> getRange2() {
        return range2;
    }

    public void setRange2(List<Integer> range2) {
        this.range2 = range2;
    }

    public List<Integer> getCondition3() {
        return condition3;
    }

    public void setCondition3(List<Integer> condition3) {
        this.condition3 = condition3;
    }

    public List<Integer> getRange3() {
        return range3;
    }

    public void setRange3(List<Integer> range3) {
        this.range3 = range3;
    }

    public List<Integer> getCondition4() {
        return condition4;
    }

    public void setCondition4(List<Integer> condition4) {
        this.condition4 = condition4;
    }

    public List<Integer> getRange4() {
        return range4;
    }

    public void setRange4(List<Integer> range4) {
        this.range4 = range4;
    }

    public Integer getDoubleRate() {
        return doubleRate;
    }

    public void setDoubleRate(Integer doubleRate) {
        this.doubleRate = doubleRate;
    }

    public Integer getDoubleTimesLimit() {
        return doubleTimesLimit;
    }

    public void setDoubleTimesLimit(Integer doubleTimesLimit) {
        this.doubleTimesLimit = doubleTimesLimit;
    }

    public Integer getInteractionRate() {
        return interactionRate;
    }

    public void setInteractionRate(Integer interactionRate) {
        this.interactionRate = interactionRate;
    }

    public Integer getInteractionTimes() {
        return interactionTimes;
    }

    public void setInteractionTimes(Integer interactionTimes) {
        this.interactionTimes = interactionTimes;
    }

    public Integer getVideoRate() {
        return videoRate;
    }

    public void setVideoRate(Integer videoRate) {
        this.videoRate = videoRate;
    }

    public Integer getVideoRateTimes() {
        return videoRateTimes;
    }

    public void setVideoRateTimes(Integer videoRateTimes) {
        this.videoRateTimes = videoRateTimes;
    }
}

==> tuia-ecb-center-api-1.1.0.43-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixCashCowConfigReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;
import java.util.List;

public class MixCashCowConfigReq implements Serializable {
    private static final long serialVersionUID = -44975824246569508L;

    /*金币的成熟时间*/
    private Integer matureTime;

    /*新手引导金币数*/
    private Integer gainAtGuide;

    /*获得金币的区间配置 前N个 默认为5个*/
    private List<Integer> condition1;

    /*3-5*/
    private List<Integer> range1;

    /*获得金币的区间配置 前N个 默认为6-20个*/
    private List<Integer> condition2;

    /*3-5*/
    private List<Integer> range2;

    /*获得金币的区间配置 前N个 默认为21-50个*/
    private List<Integer> condition3;

    /*2-4*/
    private List<Integer> range3;

    /*获得金币的区间配置 前N个 默认为大于50个*/
    private List<Integer> condition4;

    /*1-2*/
    private List<Integer> range4;

    /*金币翻倍概率*/
    private Integer doubleRate;

    /*触发次数上线*/
    private Integer doubleTimesLimit;

    /*互动的概率*/
    private Integer interactionRate;

    /*互动的倍数*/
    private Integer interactionTimes;

    /*视频的概率*/
    private Integer videoRate;

    /*视频的倍数*/
    private Integer videoRateTimes;

    /*翻倍倍数*/
    private Integer doubleTimes;

    public Integer getMatureTime() {
        return matureTime;
    }

    public void setMatureTime(Integer matureTime) {
        this.matureTime = matureTime;
    }

    public Integer getGainAtGuide() {
        return gainAtGuide;
    }

    public void setGainAtGuide(Integer gainAtGuide) {
        this.gainAtGuide = gainAtGuide;
    }

    public List<Integer> getCondition1() {
        return condition1;
    }

    public void setCondition1(List<Integer> condition1) {
        this.condition1 = condition1;
    }

    public List<Integer> getRange1() {
        return range1;
    }

    public void setRange1(List<Integer> range1) {
        this.range1 = range1;
    }

    public List<Integer> getCondition2() {
        return condition2;
    }

    public void setCondition2(List<Integer> condition2) {
        this.condition2 = condition2;
    }

    public List<Integer> getRange2() {
        return range2;
    }

    public void setRange2(List<Integer> range2) {
        this.range2 = range2;
    }

    public List<Integer> getCondition3() {
        return condition3;
    }

    public void setCondition3(List<Integer> condition3) {
        this.condition3 = condition3;
    }

    public List<Integer> getRange3() {
        return range3;
    }

    public void setRange3(List<Integer> range3) {
        this.range3 = range3;
    }

    public List<Integer> getCondition4() {
        return condition4;
    }

    public void setCondition4(List<Integer> condition4) {
        this.condition4 = condition4;
    }

    public List<Integer> getRange4() {
        return range4;
    }

    public void setRange4(List<Integer> range4) {
        this.range4 = range4;
    }

    public Integer getDoubleRate() {
        return doubleRate;
    }

    public void setDoubleRate(Integer doubleRate) {
        this.doubleRate = doubleRate;
    }

    public Integer getDoubleTimesLimit() {
        return doubleTimesLimit;
    }

    public void setDoubleTimesLimit(Integer doubleTimesLimit) {
        this.doubleTimesLimit = doubleTimesLimit;
    }

    public Integer getInteractionRate() {
        return interactionRate;
    }

    public void setInteractionRate(Integer interactionRate) {
        this.interactionRate = interactionRate;
    }

    public Integer getInteractionTimes() {
        return interactionTimes;
    }

    public void setInteractionTimes(Integer interactionTimes) {
        this.interactionTimes = interactionTimes;
    }

    public Integer getVideoRate() {
        return videoRate;
    }

    public void setVideoRate(Integer videoRate) {
        this.videoRate = videoRate;
    }

    public Integer getVideoRateTimes() {
        return videoRateTimes;
    }

    public void setVideoRateTimes(Integer videoRateTimes) {
        this.videoRateTimes = videoRateTimes;
    }

    public Integer getDoubleTimes() {
        return doubleTimes;
    }

    public void setDoubleTimes(Integer doubleTimes) {
        this.doubleTimes = doubleTimes;
    }
}
